#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2019/8/30 11:10
# @Author  : oujianhua
# @mail  : ojhtyy@163.com
# @File    : env.py

import sys
import os
#设置工作路径为运行文件的所在路径
s_BaseDir=os.path.abspath(os.path.dirname(sys.argv[0]))
sys.path.append(s_BaseDir)
os.chdir(s_BaseDir)



#!/usr/bin/python
# -*- coding: utf-8 -*-
import os

file_info = '''
 @Time    : 18/1/7 13:34
 @Author  : oujianhua
 @mail  : ojhtyy@163.com
 '''
import locale
import commands
import subprocess
from log import logger

def runCmdBak(cmd): #flag标记数据来源, 如果是conf文件则执行一次OS命令后,把结果存起来, 发送ZABBIX不传flag 不处理
    #print(cmd)
    code,output=commands.getstatusoutput(cmd)
    return output,code

#可以指定执行路径
def runCmd(cmd,dir=os.getcwd()): #flag标记数据来源, 如果是conf文件则执行一次OS命令后,把结果存起来, 发送ZABBIX不传flag 不处理
    #print(cmd)
    #logger.info(cmd)
    try:
        p = subprocess.Popen(cmd, shell=True, stdout=subprocess.PIPE,stderr=subprocess.PIPE,cwd=dir)
    except:
        return None, p.returncode
    else:
        output, err = p.communicate()
        #if len(err)>0:
        if p.returncode != 0:
            logger.error("get error:%s when run cmd: %s " % (err.decode(locale.getdefaultlocale()[1]), cmd))
            raise Exception("run cmd error")
    #return output+err, p.returncode
    #部分命令执行成功（code=0） 但输出的信息在ERR中 ，要两个都输出
    return output.decode(locale.getdefaultlocale()[1])+err.decode(locale.getdefaultlocale()[1]), p.returncode

#弃用，为兼容历史项目 改用 runCmd , 这有异常时 不太正常
def runCmdWithDir(cmd,dir): #flag标记数据来源, 如果是conf文件则执行一次OS命令后,把结果存起来, 发送ZABBIX不传flag 不处理
    #print(cmd)
    try:
        p = subprocess.Popen(cmd, stdout=subprocess.PIPE, shell=True,cwd=dir)
    except BaseException as e:
        return None, p.returncode
    else:
        output, code = p.communicate()
    return output.decode(locale.getdefaultlocale()[1]), p.returncode




#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 19/11/26 13:55
# @Author  : oujianhua
# @mail  : ojhtyy@163.com
# @File    : timeHelper.py
import datetime


#获取下次工作的秒数
from log import logger

#获取下个工作时间的秒数， 如当前时间是10:10:1 点 要获取 20点， 则取现在当天的20点的秒差， 要获取5点 ，则是获取现在到下一天的秒差
def getSleepSec(workHour):
    nowHour=datetime.datetime.now().hour
    #睡眠时长 ： 如果 现在未过当天的处理时间， 则当天处理， 如果现在已经过了处理时间，则明天处理
    nextWorkHour=workHour if nowHour<workHour else 24 + workHour
    nextWorkHourTimeForMat = datetime.datetime.strptime(str(datetime.date.today()), '%Y-%m-%d') + datetime.timedelta(seconds=nextWorkHour * 60 * 60 + 10)
    sleepSecond = round((nextWorkHourTimeForMat - datetime.datetime.now()).total_seconds())
    logger.info('sleep %s s ,next run time is %s ' % (str(sleepSecond), str(nextWorkHourTimeForMat)))
    return sleepSecond

if __name__=='__main__':
    getSleepSec(10)


#!/usr/bin/python
# -*- coding: utf-8 -*-
import os
import sys

file_info = '''
 @Time    : 18/1/7 13:34
 @Author  : oujianhua
 @mail  : ojhtyy@163.com
 引用时, 要把本第一个 import , 以免打印不出 , 如git 
 '''

import logging
from  logging import config

#如果日志目录不存在, 在当前工作目录下创建Log文件夹 ,之后如果程序使用 os.chdir 切换目录 , 也不影响


#通过调用时指定配置文件 调用时如： main.py dev|prod
try:
    env = sys.argv[1]
except BaseException as e:
    env='prod'

log_dir="logs"  #日志目录在运行路径下
work_dir=os.getcwd()
if not log_dir in os.listdir(work_dir):
     os.mkdir(os.path.join(work_dir,"logs"))
#获取配置文件
conf_file_full_path = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'conf','logging.cfg')
config.fileConfig(conf_file_full_path)

#除了开发时 ,其他情况的日志都输出到文件
if env=='dev':
    logger = logging.getLogger('console')
else:
    logger = logging.getLogger('file')
if __name__=='__main__':
    #log = logging.getLogger('root') #获取 配置文件中的 root节点 通过root节点来处理日志
    #errorlog=logging.getLogger("error")  #通过配置文件中的error 节点处理日志 ,处理的信息会交给 root 再次处理
    #errorlog.error("9898989889") #传给  error 这个 logger 处理 后, 又给到 root再次处理
    logger.error("444444444")
    logger.info("iiiiiiiiiiii")




#!/usr/bin/python
# -*- coding: utf-8 -*-
from __future__ import unicode_literals
import ConfigParser
import os
import codecs
import sys
from log import logger

#修复key全转为小写问题
class MyConfigParser(ConfigParser.SafeConfigParser):
    def __init__(self, defaults=None):
        ConfigParser.SafeConfigParser.__init__(self, defaults=defaults)
    def optionxform(self, optionstr):
        return optionstr

def read_conf(conf_file):
    if not os.path.exists(conf_file):
       raise Exception("not exists config file :%s"%(conf_file))
    else:
    #文件不存在也不处理 让调用者自己决定怎么处理该异常
        #读出来的是 unicode 编码 推荐 ,
        #config = ConfigParser.SafeConfigParser()
        config=MyConfigParser()
        with codecs.open(conf_file, 'r', encoding='utf-8') as f:
            config.readfp(f)
        return config

def main(conf_file=''):
    #没传配置文件时, 需要传环境参数 prod|dev|test 等用于对应的配置文件
    if conf_file=='':
        try:
            env=sys.argv[1]
        except BaseException as e:
            raise Exception("paramsError: usage : python main.py env  [other params ] , env use for conf file , like prod|dev|test")
        #默认取项目路径下 conf/conf_xxx 配置文件
        conf_file =os.path.join(os.getcwd(),'conf','conf_%s.cfg'%sys.argv[1])
    config=read_conf(conf_file)
    return(config)

if __name__ == '__main__':
    config=main()
    # 获取各个section 下的 所有的配置项名
    print(config.has_section('sdf'))
    for section in config.sections():
        print(config.options(section))
    for options in config.options(section):  # 获取所有 key
        print options  # key
        print(config.get(section, options))  # val
    for item in config.items(section):  # (key,val)
        print item





#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 19/11/26 11:23
# @Author  : oujianhua
# @mail  : ojhtyy@163.com
# @File    : setup.py
from __future__ import print_function
from setuptools import setup, find_packages
import sys

setup(
    name = "projhelper",
    version = "0.1.1",
    keywords = ("pip", "datacanvas", "helper", "proj"),
    description = "project base helper, include logger ",
    long_description = "eds sdk for python",
    license = "MIT Licence",

    url = "",
    author = "oujh",
    author_email = "ojhtyy@163.com",

    packages = find_packages(),
    include_package_data = True,
    platforms = "any",
    install_requires = [
        #'locale'
    ]
)